# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mongodb/v1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.type import timeofday_pb2 as google_dot_type_dot_timeofday__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb3_6_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb3__6__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__0__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_2_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__2__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_4_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb4_4_enterprise_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb4__4__enterprise__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb5_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb5_0_enterprise_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb5__0__enterprise__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb6_0_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb6__0__pb2
from yandex.cloud.mdb.mongodb.v1.config import mongodb6_0_enterprise_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_config_dot_mongodb6__0__enterprise__pb2
from yandex.cloud.mdb.mongodb.v1 import maintenance_pb2 as yandex_dot_cloud_dot_mdb_dot_mongodb_dot_v1_dot_maintenance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/mdb/mongodb/v1/cluster.proto\x12\x1byandex.cloud.mdb.mongodb.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1bgoogle/type/timeofday.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb3_6.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_0.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_2.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb4_4.proto\x1a>yandex/cloud/mdb/mongodb/v1/config/mongodb4_4_enterprise.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb5_0.proto\x1a>yandex/cloud/mdb/mongodb/v1/config/mongodb5_0_enterprise.proto\x1a\x33yandex/cloud/mdb/mongodb/v1/config/mongodb6_0.proto\x1a>yandex/cloud/mdb/mongodb/v1/config/mongodb6_0_enterprise.proto\x1a-yandex/cloud/mdb/mongodb/v1/maintenance.proto\"\xa5\x08\n\x07\x43luster\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12@\n\x06labels\x18\x06 \x03(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.Cluster.LabelsEntry\x12\x45\n\x0b\x65nvironment\x18\x07 \x01(\x0e\x32\x30.yandex.cloud.mdb.mongodb.v1.Cluster.Environment\x12;\n\nmonitoring\x18\x08 \x03(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.Monitoring\x12:\n\x06\x63onfig\x18\t \x01(\x0b\x32*.yandex.cloud.mdb.mongodb.v1.ClusterConfig\x12\x12\n\nnetwork_id\x18\n \x01(\t\x12;\n\x06health\x18\x0b \x01(\x0e\x32+.yandex.cloud.mdb.mongodb.v1.Cluster.Health\x12;\n\x06status\x18\x0c \x01(\x0e\x32+.yandex.cloud.mdb.mongodb.v1.Cluster.Status\x12\x0f\n\x07sharded\x18\r \x01(\x08\x12J\n\x12maintenance_window\x18\x0e \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.MaintenanceWindow\x12L\n\x11planned_operation\x18\x0f \x01(\x0b\x32\x31.yandex.cloud.mdb.mongodb.v1.MaintenanceOperation\x12\x1a\n\x12security_group_ids\x18\x10 \x03(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x11 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"I\n\x0b\x45nvironment\x12\x1b\n\x17\x45NVIRONMENT_UNSPECIFIED\x10\x00\x12\x0e\n\nPRODUCTION\x10\x01\x12\r\n\tPRESTABLE\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"y\n\x06Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0b\n\x07RUNNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\x12\x0c\n\x08STOPPING\x10\x05\x12\x0b\n\x07STOPPED\x10\x06\x12\x0c\n\x08STARTING\x10\x07\"=\n\nMonitoring\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04link\x18\x03 \x01(\t\"\xf0\x08\n\rClusterConfig\x12\x0f\n\x07version\x18\x01 \x01(\t\x12%\n\x1d\x66\x65\x61ture_compatibility_version\x18\x05 \x01(\t\x12K\n\x0bmongodb_3_6\x18\x02 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.Mongodb3_6H\x00R\x0bmongodb_3_6\x12K\n\x0bmongodb_4_0\x18\x04 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.Mongodb4_0H\x00R\x0bmongodb_4_0\x12K\n\x0bmongodb_4_2\x18\x07 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.Mongodb4_2H\x00R\x0bmongodb_4_2\x12K\n\x0bmongodb_4_4\x18\x08 \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.Mongodb4_4H\x00R\x0bmongodb_4_4\x12K\n\x0bmongodb_5_0\x18\n \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.Mongodb5_0H\x00R\x0bmongodb_5_0\x12K\n\x0bmongodb_6_0\x18\x0e \x01(\x0b\x32\'.yandex.cloud.mdb.mongodb.v1.Mongodb6_0H\x00R\x0bmongodb_6_0\x12l\n\x16mongodb_4_4_enterprise\x18\x0b \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb4_4_enterpriseH\x00R\x16mongodb_4_4_enterprise\x12l\n\x16mongodb_5_0_enterprise\x18\x0c \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb5_0_enterpriseH\x00R\x16mongodb_5_0_enterprise\x12l\n\x16mongodb_6_0_enterprise\x18\x0f \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb6_0_enterpriseH\x00R\x16mongodb_6_0_enterprise\x12\x33\n\x13\x62\x61\x63kup_window_start\x18\x03 \x01(\x0b\x32\x16.google.type.TimeOfDay\x12>\n\x19\x62\x61\x63kup_retain_period_days\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12Z\n\x17performance_diagnostics\x18\r \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.PerformanceDiagnosticsConfig\x12\x33\n\x06\x61\x63\x63\x65ss\x18\x06 \x01(\x0b\x32#.yandex.cloud.mdb.mongodb.v1.AccessB\t\n\x07mongodb\"\xb2\x07\n\nMongodb3_6\x12>\n\x06mongod\x18\x01 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb3_6.Mongod\x12\x42\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.Mongodb3_6.MongoCfg\x12>\n\x06mongos\x18\x03 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb3_6.Mongos\x12\x46\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb3_6.MongoInfra\x1a\x8b\x01\n\x06Mongod\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8f\x01\n\x08MongoCfg\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8b\x01\n\x06Mongos\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet3_6\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe9\x01\n\nMongoInfra\x12M\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet3_6\x12Q\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet3_6\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb2\x07\n\nMongodb4_0\x12>\n\x06mongod\x18\x01 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb4_0.Mongod\x12\x42\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.Mongodb4_0.MongoCfg\x12>\n\x06mongos\x18\x03 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb4_0.Mongos\x12\x46\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb4_0.MongoInfra\x1a\x8b\x01\n\x06Mongod\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8f\x01\n\x08MongoCfg\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8b\x01\n\x06Mongos\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe9\x01\n\nMongoInfra\x12M\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_0\x12Q\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_0\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb2\x07\n\nMongodb4_2\x12>\n\x06mongod\x18\x01 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb4_2.Mongod\x12\x42\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.Mongodb4_2.MongoCfg\x12>\n\x06mongos\x18\x03 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb4_2.Mongos\x12\x46\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb4_2.MongoInfra\x1a\x8b\x01\n\x06Mongod\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8f\x01\n\x08MongoCfg\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8b\x01\n\x06Mongos\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe9\x01\n\nMongoInfra\x12M\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_2\x12Q\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_2\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb2\x07\n\nMongodb4_4\x12>\n\x06mongod\x18\x01 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb4_4.Mongod\x12\x42\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.Mongodb4_4.MongoCfg\x12>\n\x06mongos\x18\x03 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb4_4.Mongos\x12\x46\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb4_4.MongoInfra\x1a\x8b\x01\n\x06Mongod\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8f\x01\n\x08MongoCfg\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8b\x01\n\x06Mongos\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_4\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe9\x01\n\nMongoInfra\x12M\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_4\x12Q\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_4\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xa0\x08\n\x15Mongodb4_4_enterprise\x12I\n\x06mongod\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.Mongodb4_4_enterprise.Mongod\x12M\n\x08mongocfg\x18\x02 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.Mongodb4_4_enterprise.MongoCfg\x12I\n\x06mongos\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.Mongodb4_4_enterprise.Mongos\x12Q\n\nmongoinfra\x18\x04 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.Mongodb4_4_enterprise.MongoInfra\x1a\x96\x01\n\x06Mongod\x12Q\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x9a\x01\n\x08MongoCfg\x12S\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x96\x01\n\x06Mongos\x12Q\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_4_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xff\x01\n\nMongoInfra\x12X\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet4_4_enterprise\x12\\\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet4_4_enterprise\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb2\x07\n\nMongodb5_0\x12>\n\x06mongod\x18\x01 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb5_0.Mongod\x12\x42\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.Mongodb5_0.MongoCfg\x12>\n\x06mongos\x18\x03 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb5_0.Mongos\x12\x46\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb5_0.MongoInfra\x1a\x8b\x01\n\x06Mongod\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8f\x01\n\x08MongoCfg\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8b\x01\n\x06Mongos\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet5_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe9\x01\n\nMongoInfra\x12M\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet5_0\x12Q\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet5_0\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xa0\x08\n\x15Mongodb5_0_enterprise\x12I\n\x06mongod\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.Mongodb5_0_enterprise.Mongod\x12M\n\x08mongocfg\x18\x02 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.Mongodb5_0_enterprise.MongoCfg\x12I\n\x06mongos\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.Mongodb5_0_enterprise.Mongos\x12Q\n\nmongoinfra\x18\x04 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.Mongodb5_0_enterprise.MongoInfra\x1a\x96\x01\n\x06Mongod\x12Q\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x9a\x01\n\x08MongoCfg\x12S\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x96\x01\n\x06Mongos\x12Q\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet5_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xff\x01\n\nMongoInfra\x12X\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet5_0_enterprise\x12\\\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet5_0_enterprise\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xb2\x07\n\nMongodb6_0\x12>\n\x06mongod\x18\x01 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb6_0.Mongod\x12\x42\n\x08mongocfg\x18\x02 \x01(\x0b\x32\x30.yandex.cloud.mdb.mongodb.v1.Mongodb6_0.MongoCfg\x12>\n\x06mongos\x18\x03 \x01(\x0b\x32..yandex.cloud.mdb.mongodb.v1.Mongodb6_0.Mongos\x12\x46\n\nmongoinfra\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.mdb.mongodb.v1.Mongodb6_0.MongoInfra\x1a\x8b\x01\n\x06Mongod\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet6_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8f\x01\n\x08MongoCfg\x12H\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x8b\x01\n\x06Mongos\x12\x46\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xe9\x01\n\nMongoInfra\x12M\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x36.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0\x12Q\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\"\xa0\x08\n\x15Mongodb6_0_enterprise\x12I\n\x06mongod\x18\x01 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.Mongodb6_0_enterprise.Mongod\x12M\n\x08mongocfg\x18\x02 \x01(\x0b\x32;.yandex.cloud.mdb.mongodb.v1.Mongodb6_0_enterprise.MongoCfg\x12I\n\x06mongos\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.mdb.mongodb.v1.Mongodb6_0_enterprise.Mongos\x12Q\n\nmongoinfra\x18\x04 \x01(\x0b\x32=.yandex.cloud.mdb.mongodb.v1.Mongodb6_0_enterprise.MongoInfra\x1a\x96\x01\n\x06Mongod\x12Q\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongodConfigSet6_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x9a\x01\n\x08MongoCfg\x12S\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\x96\x01\n\x06Mongos\x12Q\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0_enterprise\x12\x39\n\tresources\x18\x02 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x1a\xff\x01\n\nMongoInfra\x12X\n\rconfig_mongos\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.mdb.mongodb.v1.config.MongosConfigSet6_0_enterprise\x12\\\n\x0f\x63onfig_mongocfg\x18\x02 \x01(\x0b\x32\x43.yandex.cloud.mdb.mongodb.v1.config.MongoCfgConfigSet6_0_enterprise\x12\x39\n\tresources\x18\x03 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\")\n\x05Shard\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\"\xde\x04\n\x04Host\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12\x0f\n\x07zone_id\x18\x03 \x01(\t\x12\x39\n\tresources\x18\x04 \x01(\x0b\x32&.yandex.cloud.mdb.mongodb.v1.Resources\x12\x34\n\x04role\x18\x05 \x01(\x0e\x32&.yandex.cloud.mdb.mongodb.v1.Host.Role\x12\x38\n\x06health\x18\x06 \x01(\x0e\x32(.yandex.cloud.mdb.mongodb.v1.Host.Health\x12\x36\n\x08services\x18\x07 \x03(\x0b\x32$.yandex.cloud.mdb.mongodb.v1.Service\x12\x11\n\tsubnet_id\x18\x08 \x01(\t\x12\x18\n\x10\x61ssign_public_ip\x18\t \x01(\x08\x12\x12\n\nshard_name\x18\n \x01(\t\x12\x34\n\x04type\x18\x0b \x01(\x0e\x32&.yandex.cloud.mdb.mongodb.v1.Host.Type\"R\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MONGOD\x10\x01\x12\n\n\x06MONGOS\x10\x02\x12\x0c\n\x08MONGOCFG\x10\x03\x12\x0e\n\nMONGOINFRA\x10\x04\"4\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\x0b\n\x07PRIMARY\x10\x01\x12\r\n\tSECONDARY\x10\x02\"?\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\"\xf6\x01\n\x07Service\x12\x37\n\x04type\x18\x01 \x01(\x0e\x32).yandex.cloud.mdb.mongodb.v1.Service.Type\x12;\n\x06health\x18\x02 \x01(\x0e\x32+.yandex.cloud.mdb.mongodb.v1.Service.Health\"B\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06MONGOD\x10\x01\x12\n\n\x06MONGOS\x10\x02\x12\x0c\n\x08MONGOCFG\x10\x03\"1\n\x06Health\x12\x12\n\x0eHEALTH_UNKNOWN\x10\x00\x12\t\n\x05\x41LIVE\x10\x01\x12\x08\n\x04\x44\x45\x41\x44\x10\x02\"P\n\tResources\x12\x1a\n\x12resource_preset_id\x18\x01 \x01(\t\x12\x11\n\tdisk_size\x18\x02 \x01(\x03\x12\x14\n\x0c\x64isk_type_id\x18\x03 \x01(\t\"2\n\x06\x41\x63\x63\x65ss\x12\x11\n\tdata_lens\x18\x01 \x01(\x08\x12\x15\n\rdata_transfer\x18\x03 \x01(\x08\"9\n\x1cPerformanceDiagnosticsConfig\x12\x19\n\x11profiling_enabled\x18\x01 \x01(\x08\x42j\n\x1fyandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mongodb.v1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\037yandex.cloud.api.mdb.mongodb.v1ZGgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mongodb/v1;mongodb'
  _CLUSTER_LABELSENTRY._options = None
  _CLUSTER_LABELSENTRY._serialized_options = b'8\001'
  _globals['_CLUSTER']._serialized_start=726
  _globals['_CLUSTER']._serialized_end=1787
  _globals['_CLUSTER_LABELSENTRY']._serialized_start=1479
  _globals['_CLUSTER_LABELSENTRY']._serialized_end=1524
  _globals['_CLUSTER_ENVIRONMENT']._serialized_start=1526
  _globals['_CLUSTER_ENVIRONMENT']._serialized_end=1599
  _globals['_CLUSTER_HEALTH']._serialized_start=1601
  _globals['_CLUSTER_HEALTH']._serialized_end=1664
  _globals['_CLUSTER_STATUS']._serialized_start=1666
  _globals['_CLUSTER_STATUS']._serialized_end=1787
  _globals['_MONITORING']._serialized_start=1789
  _globals['_MONITORING']._serialized_end=1850
  _globals['_CLUSTERCONFIG']._serialized_start=1853
  _globals['_CLUSTERCONFIG']._serialized_end=2989
  _globals['_MONGODB3_6']._serialized_start=2992
  _globals['_MONGODB3_6']._serialized_end=3938
  _globals['_MONGODB3_6_MONGOD']._serialized_start=3275
  _globals['_MONGODB3_6_MONGOD']._serialized_end=3414
  _globals['_MONGODB3_6_MONGOCFG']._serialized_start=3417
  _globals['_MONGODB3_6_MONGOCFG']._serialized_end=3560
  _globals['_MONGODB3_6_MONGOS']._serialized_start=3563
  _globals['_MONGODB3_6_MONGOS']._serialized_end=3702
  _globals['_MONGODB3_6_MONGOINFRA']._serialized_start=3705
  _globals['_MONGODB3_6_MONGOINFRA']._serialized_end=3938
  _globals['_MONGODB4_0']._serialized_start=3941
  _globals['_MONGODB4_0']._serialized_end=4887
  _globals['_MONGODB4_0_MONGOD']._serialized_start=4224
  _globals['_MONGODB4_0_MONGOD']._serialized_end=4363
  _globals['_MONGODB4_0_MONGOCFG']._serialized_start=4366
  _globals['_MONGODB4_0_MONGOCFG']._serialized_end=4509
  _globals['_MONGODB4_0_MONGOS']._serialized_start=4512
  _globals['_MONGODB4_0_MONGOS']._serialized_end=4651
  _globals['_MONGODB4_0_MONGOINFRA']._serialized_start=4654
  _globals['_MONGODB4_0_MONGOINFRA']._serialized_end=4887
  _globals['_MONGODB4_2']._serialized_start=4890
  _globals['_MONGODB4_2']._serialized_end=5836
  _globals['_MONGODB4_2_MONGOD']._serialized_start=5173
  _globals['_MONGODB4_2_MONGOD']._serialized_end=5312
  _globals['_MONGODB4_2_MONGOCFG']._serialized_start=5315
  _globals['_MONGODB4_2_MONGOCFG']._serialized_end=5458
  _globals['_MONGODB4_2_MONGOS']._serialized_start=5461
  _globals['_MONGODB4_2_MONGOS']._serialized_end=5600
  _globals['_MONGODB4_2_MONGOINFRA']._serialized_start=5603
  _globals['_MONGODB4_2_MONGOINFRA']._serialized_end=5836
  _globals['_MONGODB4_4']._serialized_start=5839
  _globals['_MONGODB4_4']._serialized_end=6785
  _globals['_MONGODB4_4_MONGOD']._serialized_start=6122
  _globals['_MONGODB4_4_MONGOD']._serialized_end=6261
  _globals['_MONGODB4_4_MONGOCFG']._serialized_start=6264
  _globals['_MONGODB4_4_MONGOCFG']._serialized_end=6407
  _globals['_MONGODB4_4_MONGOS']._serialized_start=6410
  _globals['_MONGODB4_4_MONGOS']._serialized_end=6549
  _globals['_MONGODB4_4_MONGOINFRA']._serialized_start=6552
  _globals['_MONGODB4_4_MONGOINFRA']._serialized_end=6785
  _globals['_MONGODB4_4_ENTERPRISE']._serialized_start=6788
  _globals['_MONGODB4_4_ENTERPRISE']._serialized_end=7844
  _globals['_MONGODB4_4_ENTERPRISE_MONGOD']._serialized_start=7126
  _globals['_MONGODB4_4_ENTERPRISE_MONGOD']._serialized_end=7276
  _globals['_MONGODB4_4_ENTERPRISE_MONGOCFG']._serialized_start=7279
  _globals['_MONGODB4_4_ENTERPRISE_MONGOCFG']._serialized_end=7433
  _globals['_MONGODB4_4_ENTERPRISE_MONGOS']._serialized_start=7436
  _globals['_MONGODB4_4_ENTERPRISE_MONGOS']._serialized_end=7586
  _globals['_MONGODB4_4_ENTERPRISE_MONGOINFRA']._serialized_start=7589
  _globals['_MONGODB4_4_ENTERPRISE_MONGOINFRA']._serialized_end=7844
  _globals['_MONGODB5_0']._serialized_start=7847
  _globals['_MONGODB5_0']._serialized_end=8793
  _globals['_MONGODB5_0_MONGOD']._serialized_start=8130
  _globals['_MONGODB5_0_MONGOD']._serialized_end=8269
  _globals['_MONGODB5_0_MONGOCFG']._serialized_start=8272
  _globals['_MONGODB5_0_MONGOCFG']._serialized_end=8415
  _globals['_MONGODB5_0_MONGOS']._serialized_start=8418
  _globals['_MONGODB5_0_MONGOS']._serialized_end=8557
  _globals['_MONGODB5_0_MONGOINFRA']._serialized_start=8560
  _globals['_MONGODB5_0_MONGOINFRA']._serialized_end=8793
  _globals['_MONGODB5_0_ENTERPRISE']._serialized_start=8796
  _globals['_MONGODB5_0_ENTERPRISE']._serialized_end=9852
  _globals['_MONGODB5_0_ENTERPRISE_MONGOD']._serialized_start=9134
  _globals['_MONGODB5_0_ENTERPRISE_MONGOD']._serialized_end=9284
  _globals['_MONGODB5_0_ENTERPRISE_MONGOCFG']._serialized_start=9287
  _globals['_MONGODB5_0_ENTERPRISE_MONGOCFG']._serialized_end=9441
  _globals['_MONGODB5_0_ENTERPRISE_MONGOS']._serialized_start=9444
  _globals['_MONGODB5_0_ENTERPRISE_MONGOS']._serialized_end=9594
  _globals['_MONGODB5_0_ENTERPRISE_MONGOINFRA']._serialized_start=9597
  _globals['_MONGODB5_0_ENTERPRISE_MONGOINFRA']._serialized_end=9852
  _globals['_MONGODB6_0']._serialized_start=9855
  _globals['_MONGODB6_0']._serialized_end=10801
  _globals['_MONGODB6_0_MONGOD']._serialized_start=10138
  _globals['_MONGODB6_0_MONGOD']._serialized_end=10277
  _globals['_MONGODB6_0_MONGOCFG']._serialized_start=10280
  _globals['_MONGODB6_0_MONGOCFG']._serialized_end=10423
  _globals['_MONGODB6_0_MONGOS']._serialized_start=10426
  _globals['_MONGODB6_0_MONGOS']._serialized_end=10565
  _globals['_MONGODB6_0_MONGOINFRA']._serialized_start=10568
  _globals['_MONGODB6_0_MONGOINFRA']._serialized_end=10801
  _globals['_MONGODB6_0_ENTERPRISE']._serialized_start=10804
  _globals['_MONGODB6_0_ENTERPRISE']._serialized_end=11860
  _globals['_MONGODB6_0_ENTERPRISE_MONGOD']._serialized_start=11142
  _globals['_MONGODB6_0_ENTERPRISE_MONGOD']._serialized_end=11292
  _globals['_MONGODB6_0_ENTERPRISE_MONGOCFG']._serialized_start=11295
  _globals['_MONGODB6_0_ENTERPRISE_MONGOCFG']._serialized_end=11449
  _globals['_MONGODB6_0_ENTERPRISE_MONGOS']._serialized_start=11452
  _globals['_MONGODB6_0_ENTERPRISE_MONGOS']._serialized_end=11602
  _globals['_MONGODB6_0_ENTERPRISE_MONGOINFRA']._serialized_start=11605
  _globals['_MONGODB6_0_ENTERPRISE_MONGOINFRA']._serialized_end=11860
  _globals['_SHARD']._serialized_start=11862
  _globals['_SHARD']._serialized_end=11903
  _globals['_HOST']._serialized_start=11906
  _globals['_HOST']._serialized_end=12512
  _globals['_HOST_TYPE']._serialized_start=12311
  _globals['_HOST_TYPE']._serialized_end=12393
  _globals['_HOST_ROLE']._serialized_start=12395
  _globals['_HOST_ROLE']._serialized_end=12447
  _globals['_HOST_HEALTH']._serialized_start=1601
  _globals['_HOST_HEALTH']._serialized_end=1664
  _globals['_SERVICE']._serialized_start=12515
  _globals['_SERVICE']._serialized_end=12761
  _globals['_SERVICE_TYPE']._serialized_start=12311
  _globals['_SERVICE_TYPE']._serialized_end=12377
  _globals['_SERVICE_HEALTH']._serialized_start=1601
  _globals['_SERVICE_HEALTH']._serialized_end=1650
  _globals['_RESOURCES']._serialized_start=12763
  _globals['_RESOURCES']._serialized_end=12843
  _globals['_ACCESS']._serialized_start=12845
  _globals['_ACCESS']._serialized_end=12895
  _globals['_PERFORMANCEDIAGNOSTICSCONFIG']._serialized_start=12897
  _globals['_PERFORMANCEDIAGNOSTICSCONFIG']._serialized_end=12954
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/billing/v1/service_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.billing.v1 import service_pb2 as yandex_dot_cloud_dot_billing_dot_v1_dot_service__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-yandex/cloud/billing/v1/service_service.proto\x12\x17yandex.cloud.billing.v1\x1a\x1cgoogle/api/annotations.proto\x1a%yandex/cloud/billing/v1/service.proto\x1a\x1dyandex/cloud/validation.proto\"-\n\x11GetServiceRequest\x12\x18\n\x02id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"o\n\x13ListServicesRequest\x12\x1a\n\x06\x66ilter\x18\x01 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"c\n\x14ListServicesResponse\x12\x32\n\x08services\x18\x01 \x03(\x0b\x32 .yandex.cloud.billing.v1.Service\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x8c\x02\n\x0eServiceService\x12v\n\x03Get\x12*.yandex.cloud.billing.v1.GetServiceRequest\x1a .yandex.cloud.billing.v1.Service\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/billing/v1/services/{id}\x12\x81\x01\n\x04List\x12,.yandex.cloud.billing.v1.ListServicesRequest\x1a-.yandex.cloud.billing.v1.ListServicesResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/billing/v1/servicesBb\n\x1byandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.billing.v1.service_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.billing.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/billing/v1;billing'
  _GETSERVICEREQUEST.fields_by_name['id']._options = None
  _GETSERVICEREQUEST.fields_by_name['id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTSERVICESREQUEST.fields_by_name['filter']._options = None
  _LISTSERVICESREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _LISTSERVICESREQUEST.fields_by_name['page_size']._options = None
  _LISTSERVICESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTSERVICESREQUEST.fields_by_name['page_token']._options = None
  _LISTSERVICESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _SERVICESERVICE.methods_by_name['Get']._options = None
  _SERVICESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\033\022\031/billing/v1/services/{id}'
  _SERVICESERVICE.methods_by_name['List']._options = None
  _SERVICESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\026\022\024/billing/v1/services'
  _globals['_GETSERVICEREQUEST']._serialized_start=174
  _globals['_GETSERVICEREQUEST']._serialized_end=219
  _globals['_LISTSERVICESREQUEST']._serialized_start=221
  _globals['_LISTSERVICESREQUEST']._serialized_end=332
  _globals['_LISTSERVICESRESPONSE']._serialized_start=334
  _globals['_LISTSERVICESRESPONSE']._serialized_end=433
  _globals['_SERVICESERVICE']._serialized_start=436
  _globals['_SERVICESERVICE']._serialized_end=704
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/greenplum/v1/pxf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/mdb/greenplum/v1/pxf.proto\x12\x1dyandex.cloud.mdb.greenplum.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xc5\x04\n\tPXFConfig\x12\x42\n\x12\x63onnection_timeout\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12>\n\x0eupload_timeout\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12<\n\x0bmax_threads\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x42\n\x1epool_allow_core_thread_timeout\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0epool_core_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x41\n\x13pool_queue_capacity\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12>\n\rpool_max_size\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31-1024\x12\x36\n\x03xmx\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x36\x34-16384\x12\x36\n\x03xms\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x36\x34-16384\"\xd9\x01\n\x0cPXFConfigSet\x12H\n\x10\x65\x66\x66\x65\x63tive_config\x18\x01 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfigB\x04\xe8\xc7\x31\x01\x12=\n\x0buser_config\x18\x02 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfig\x12@\n\x0e\x64\x65\x66\x61ult_config\x18\x03 \x01(\x0b\x32(.yandex.cloud.mdb.greenplum.v1.PXFConfig\"\x9d\x01\n\x0fPXFDatasourceS3\x12\x1d\n\naccess_key\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1d\n\nsecret_key\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12/\n\x0b\x66\x61st_upload\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x08\x65ndpoint\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=200\"\xa6\x05\n\x11PXFDatasourceJDBC\x12\x18\n\x06\x64river\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x16\n\x03url\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x17\n\x04user\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x1b\n\x08password\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12\x46\n\x14statement_batch_size\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0b\xfa\xc7\x31\x07\x35\x30-1000\x12G\n\x14statement_fetch_size\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0c\xfa\xc7\x31\x08\x35\x30-10000\x12G\n\x17statement_query_timeout\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x35-600\x12\x30\n\x0cpool_enabled\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\x11pool_maximum_size\x18\t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\n\xfa\xc7\x31\x06\x31\x30-200\x12M\n\x17pool_connection_timeout\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0f\xfa\xc7\x31\x0b\x35\x30\x30\x30-600000\x12G\n\x11pool_idle_timeout\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x0f\xfa\xc7\x31\x0b\x35\x30\x30\x30-600000\x12\x41\n\x11pool_minimum_idle\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\t\xfa\xc7\x31\x05\x30-200\"^\n\x11PXFDatasourceCore\x12\x1d\n\ndefault_fs\x18\x01 \x01(\tB\t\x8a\xc8\x31\x05<=200\x12*\n\x16security_auth_to_local\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xcf\x02\n\x15PXFDatasourceKerberos\x12*\n\x06\x65nable\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1a\n\x07primary\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x19\n\x05realm\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\'\n\x0bkdc_servers\x18\x04 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\x1f\n\x0c\x61\x64min_server\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12!\n\x0e\x64\x65\x66\x61ult_domain\x18\x06 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x66\n\rkeytab_base64\x18\x07 \x01(\tBO\xf2\xc7\x31@^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$\x8a\xc8\x31\x07<=65536\"\xad\x01\n\x1cPXFDatasourceHDFSDfsNamenode\x12\x1f\n\x0brpc_address\x18\x01 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12\'\n\x13service_rpc_address\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12 \n\x0chttp_address\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12!\n\rhttps_address\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xa7\x03\n\x14PXFDatasourceHDFSDfs\x12\x41\n\x1dha_automatic_failover_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12>\n\x1a\x62lock_access_token_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x39\n\x15use_datanode_hostname\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x62\n\tnamenodes\x18\x04 \x03(\x0b\x32\x42.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfs.NamenodesEntryB\x0b\x82\xc8\x31\x07<=10000\x1am\n\x0eNamenodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12J\n\x05value\x18\x02 \x01(\x0b\x32;.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfsNamenode:\x02\x38\x01\"\x96\x02\n\x19PXFDatasourceHDFSYarnHaRm\x12\x1f\n\x17resourcemanager_address\x18\x01 \x01(\t\x12)\n!resourcemanager_scheduler_address\x18\x02 \x01(\t\x12\x30\n(resourcemanager_resource_tracker_address\x18\x03 \x01(\t\x12%\n\x1dresourcemanager_admin_address\x18\x04 \x01(\t\x12&\n\x1eresourcemanager_webapp_address\x18\x05 \x01(\t\x12,\n$resourcemanager_webapp_https_address\x18\x06 \x01(\t\"\xe7\x03\n\x15PXFDatasourceHDFSYarn\x12>\n\x1aresourcemanager_ha_enabled\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12L\n(resourcemanager_ha_auto_failover_enabled\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12M\n)resourcemanager_ha_auto_failover_embedded\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12.\n\x1aresourcemanager_cluster_id\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12Z\n\x05ha_rm\x18\x05 \x03(\x0b\x32>.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarn.HaRmEntryB\x0b\x82\xc8\x31\x07<=10000\x1a\x65\n\tHaRmEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12G\n\x05value\x18\x02 \x01(\x0b\x32\x38.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarnHaRm:\x02\x38\x01\"\xe4\x03\n\x11PXFDatasourceHDFS\x12>\n\x04\x63ore\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceCore\x12\x46\n\x08kerberos\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceKerberos\x12\x36\n\x12user_impersonation\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x08username\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x46\n\x17sasl_connection_retries\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-50\x12$\n\x08zk_hosts\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12@\n\x03\x64\x66s\x18\x07 \x01(\x0b\x32\x33.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSDfs\x12\x42\n\x04yarn\x18\x08 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSYarn\"\x92\x04\n\x11PXFDatasourceHive\x12>\n\x04\x63ore\x18\x01 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceCore\x12\x46\n\x08kerberos\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.mdb.greenplum.v1.PXFDatasourceKerberos\x12\x36\n\x12user_impersonation\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x1b\n\x08username\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=128\x12\x46\n\x17sasl_connection_retries\x18\x05 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x08\xfa\xc7\x31\x04\x31-50\x12$\n\x08zk_hosts\x18\x06 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\'\n\x03ppd\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12*\n\x0emetastore_uris\x18\x08 \x03(\tB\x12\x82\xc8\x31\x05<=200\x8a\xc8\x31\x05\x31-200\x12\x30\n\x1cmetastore_kerberos_principal\x18\t \x01(\tB\n\x8a\xc8\x31\x06<=1000\x12+\n\x17\x61uth_kerberos_principal\x18\n \x01(\tB\n\x8a\xc8\x31\x06<=1000\"\xbc\x02\n\rPXFDatasource\x12\x1b\n\x04name\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x33-200\x12<\n\x02s3\x18\x02 \x01(\x0b\x32..yandex.cloud.mdb.greenplum.v1.PXFDatasourceS3H\x00\x12@\n\x04jdbc\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceJDBCH\x00\x12@\n\x04hdfs\x18\x04 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHDFSH\x00\x12@\n\x04hive\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.mdb.greenplum.v1.PXFDatasourceHiveH\x00\x42\n\n\x08settingsBp\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplumb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.greenplum.v1.pxf_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n!yandex.cloud.api.mdb.greenplum.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/greenplum/v1;greenplum'
  _PXFCONFIG.fields_by_name['connection_timeout']._options = None
  _PXFCONFIG.fields_by_name['connection_timeout']._serialized_options = b'\372\3071\0055-600'
  _PXFCONFIG.fields_by_name['upload_timeout']._options = None
  _PXFCONFIG.fields_by_name['upload_timeout']._serialized_options = b'\372\3071\0055-600'
  _PXFCONFIG.fields_by_name['max_threads']._options = None
  _PXFCONFIG.fields_by_name['max_threads']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['pool_core_size']._options = None
  _PXFCONFIG.fields_by_name['pool_core_size']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['pool_queue_capacity']._options = None
  _PXFCONFIG.fields_by_name['pool_queue_capacity']._serialized_options = b'\372\3071\003>=0'
  _PXFCONFIG.fields_by_name['pool_max_size']._options = None
  _PXFCONFIG.fields_by_name['pool_max_size']._serialized_options = b'\372\3071\0061-1024'
  _PXFCONFIG.fields_by_name['xmx']._options = None
  _PXFCONFIG.fields_by_name['xmx']._serialized_options = b'\372\3071\01064-16384'
  _PXFCONFIG.fields_by_name['xms']._options = None
  _PXFCONFIG.fields_by_name['xms']._serialized_options = b'\372\3071\01064-16384'
  _PXFCONFIGSET.fields_by_name['effective_config']._options = None
  _PXFCONFIGSET.fields_by_name['effective_config']._serialized_options = b'\350\3071\001'
  _PXFDATASOURCES3.fields_by_name['access_key']._options = None
  _PXFDATASOURCES3.fields_by_name['access_key']._serialized_options = b'\212\3101\005<=200'
  _PXFDATASOURCES3.fields_by_name['secret_key']._options = None
  _PXFDATASOURCES3.fields_by_name['secret_key']._serialized_options = b'\212\3101\005<=200'
  _PXFDATASOURCES3.fields_by_name['endpoint']._options = None
  _PXFDATASOURCES3.fields_by_name['endpoint']._serialized_options = b'\212\3101\005<=200'
  _PXFDATASOURCEJDBC.fields_by_name['driver']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['driver']._serialized_options = b'\212\3101\004<=50'
  _PXFDATASOURCEJDBC.fields_by_name['url']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['url']._serialized_options = b'\212\3101\005<=200'
  _PXFDATASOURCEJDBC.fields_by_name['user']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['user']._serialized_options = b'\212\3101\005<=200'
  _PXFDATASOURCEJDBC.fields_by_name['password']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['password']._serialized_options = b'\212\3101\005<=200'
  _PXFDATASOURCEJDBC.fields_by_name['statement_batch_size']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['statement_batch_size']._serialized_options = b'\372\3071\00750-1000'
  _PXFDATASOURCEJDBC.fields_by_name['statement_fetch_size']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['statement_fetch_size']._serialized_options = b'\372\3071\01050-10000'
  _PXFDATASOURCEJDBC.fields_by_name['statement_query_timeout']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['statement_query_timeout']._serialized_options = b'\372\3071\0055-600'
  _PXFDATASOURCEJDBC.fields_by_name['pool_maximum_size']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['pool_maximum_size']._serialized_options = b'\372\3071\00610-200'
  _PXFDATASOURCEJDBC.fields_by_name['pool_connection_timeout']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['pool_connection_timeout']._serialized_options = b'\372\3071\0135000-600000'
  _PXFDATASOURCEJDBC.fields_by_name['pool_idle_timeout']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['pool_idle_timeout']._serialized_options = b'\372\3071\0135000-600000'
  _PXFDATASOURCEJDBC.fields_by_name['pool_minimum_idle']._options = None
  _PXFDATASOURCEJDBC.fields_by_name['pool_minimum_idle']._serialized_options = b'\372\3071\0050-200'
  _PXFDATASOURCECORE.fields_by_name['default_fs']._options = None
  _PXFDATASOURCECORE.fields_by_name['default_fs']._serialized_options = b'\212\3101\005<=200'
  _PXFDATASOURCECORE.fields_by_name['security_auth_to_local']._options = None
  _PXFDATASOURCECORE.fields_by_name['security_auth_to_local']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCEKERBEROS.fields_by_name['primary']._options = None
  _PXFDATASOURCEKERBEROS.fields_by_name['primary']._serialized_options = b'\212\3101\005<=128'
  _PXFDATASOURCEKERBEROS.fields_by_name['realm']._options = None
  _PXFDATASOURCEKERBEROS.fields_by_name['realm']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCEKERBEROS.fields_by_name['kdc_servers']._options = None
  _PXFDATASOURCEKERBEROS.fields_by_name['kdc_servers']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _PXFDATASOURCEKERBEROS.fields_by_name['admin_server']._options = None
  _PXFDATASOURCEKERBEROS.fields_by_name['admin_server']._serialized_options = b'\212\3101\005<=128'
  _PXFDATASOURCEKERBEROS.fields_by_name['default_domain']._options = None
  _PXFDATASOURCEKERBEROS.fields_by_name['default_domain']._serialized_options = b'\212\3101\005<=128'
  _PXFDATASOURCEKERBEROS.fields_by_name['keytab_base64']._options = None
  _PXFDATASOURCEKERBEROS.fields_by_name['keytab_base64']._serialized_options = b'\362\3071@^(?:[A-Za-z0-9+/]{4})*(?:[A-Za-z0-9+/]{2}==|[A-Za-z0-9+/]{3}=)?$\212\3101\007<=65536'
  _PXFDATASOURCEHDFSDFSNAMENODE.fields_by_name['rpc_address']._options = None
  _PXFDATASOURCEHDFSDFSNAMENODE.fields_by_name['rpc_address']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCEHDFSDFSNAMENODE.fields_by_name['service_rpc_address']._options = None
  _PXFDATASOURCEHDFSDFSNAMENODE.fields_by_name['service_rpc_address']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCEHDFSDFSNAMENODE.fields_by_name['http_address']._options = None
  _PXFDATASOURCEHDFSDFSNAMENODE.fields_by_name['http_address']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCEHDFSDFSNAMENODE.fields_by_name['https_address']._options = None
  _PXFDATASOURCEHDFSDFSNAMENODE.fields_by_name['https_address']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCEHDFSDFS_NAMENODESENTRY._options = None
  _PXFDATASOURCEHDFSDFS_NAMENODESENTRY._serialized_options = b'8\001'
  _PXFDATASOURCEHDFSDFS.fields_by_name['namenodes']._options = None
  _PXFDATASOURCEHDFSDFS.fields_by_name['namenodes']._serialized_options = b'\202\3101\007<=10000'
  _PXFDATASOURCEHDFSYARN_HARMENTRY._options = None
  _PXFDATASOURCEHDFSYARN_HARMENTRY._serialized_options = b'8\001'
  _PXFDATASOURCEHDFSYARN.fields_by_name['resourcemanager_cluster_id']._options = None
  _PXFDATASOURCEHDFSYARN.fields_by_name['resourcemanager_cluster_id']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCEHDFSYARN.fields_by_name['ha_rm']._options = None
  _PXFDATASOURCEHDFSYARN.fields_by_name['ha_rm']._serialized_options = b'\202\3101\007<=10000'
  _PXFDATASOURCEHDFS.fields_by_name['username']._options = None
  _PXFDATASOURCEHDFS.fields_by_name['username']._serialized_options = b'\212\3101\005<=128'
  _PXFDATASOURCEHDFS.fields_by_name['sasl_connection_retries']._options = None
  _PXFDATASOURCEHDFS.fields_by_name['sasl_connection_retries']._serialized_options = b'\372\3071\0041-50'
  _PXFDATASOURCEHDFS.fields_by_name['zk_hosts']._options = None
  _PXFDATASOURCEHDFS.fields_by_name['zk_hosts']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _PXFDATASOURCEHIVE.fields_by_name['username']._options = None
  _PXFDATASOURCEHIVE.fields_by_name['username']._serialized_options = b'\212\3101\005<=128'
  _PXFDATASOURCEHIVE.fields_by_name['sasl_connection_retries']._options = None
  _PXFDATASOURCEHIVE.fields_by_name['sasl_connection_retries']._serialized_options = b'\372\3071\0041-50'
  _PXFDATASOURCEHIVE.fields_by_name['zk_hosts']._options = None
  _PXFDATASOURCEHIVE.fields_by_name['zk_hosts']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _PXFDATASOURCEHIVE.fields_by_name['metastore_uris']._options = None
  _PXFDATASOURCEHIVE.fields_by_name['metastore_uris']._serialized_options = b'\202\3101\005<=200\212\3101\0051-200'
  _PXFDATASOURCEHIVE.fields_by_name['metastore_kerberos_principal']._options = None
  _PXFDATASOURCEHIVE.fields_by_name['metastore_kerberos_principal']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCEHIVE.fields_by_name['auth_kerberos_principal']._options = None
  _PXFDATASOURCEHIVE.fields_by_name['auth_kerberos_principal']._serialized_options = b'\212\3101\006<=1000'
  _PXFDATASOURCE.fields_by_name['name']._options = None
  _PXFDATASOURCE.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\0053-200'
  _globals['_PXFCONFIG']._serialized_start=138
  _globals['_PXFCONFIG']._serialized_end=719
  _globals['_PXFCONFIGSET']._serialized_start=722
  _globals['_PXFCONFIGSET']._serialized_end=939
  _globals['_PXFDATASOURCES3']._serialized_start=942
  _globals['_PXFDATASOURCES3']._serialized_end=1099
  _globals['_PXFDATASOURCEJDBC']._serialized_start=1102
  _globals['_PXFDATASOURCEJDBC']._serialized_end=1780
  _globals['_PXFDATASOURCECORE']._serialized_start=1782
  _globals['_PXFDATASOURCECORE']._serialized_end=1876
  _globals['_PXFDATASOURCEKERBEROS']._serialized_start=1879
  _globals['_PXFDATASOURCEKERBEROS']._serialized_end=2214
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE']._serialized_start=2217
  _globals['_PXFDATASOURCEHDFSDFSNAMENODE']._serialized_end=2390
  _globals['_PXFDATASOURCEHDFSDFS']._serialized_start=2393
  _globals['_PXFDATASOURCEHDFSDFS']._serialized_end=2816
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._serialized_start=2707
  _globals['_PXFDATASOURCEHDFSDFS_NAMENODESENTRY']._serialized_end=2816
  _globals['_PXFDATASOURCEHDFSYARNHARM']._serialized_start=2819
  _globals['_PXFDATASOURCEHDFSYARNHARM']._serialized_end=3097
  _globals['_PXFDATASOURCEHDFSYARN']._serialized_start=3100
  _globals['_PXFDATASOURCEHDFSYARN']._serialized_end=3587
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._serialized_start=3486
  _globals['_PXFDATASOURCEHDFSYARN_HARMENTRY']._serialized_end=3587
  _globals['_PXFDATASOURCEHDFS']._serialized_start=3590
  _globals['_PXFDATASOURCEHDFS']._serialized_end=4074
  _globals['_PXFDATASOURCEHIVE']._serialized_start=4077
  _globals['_PXFDATASOURCEHIVE']._serialized_end=4607
  _globals['_PXFDATASOURCE']._serialized_start=4610
  _globals['_PXFDATASOURCE']._serialized_end=4926
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/functions/v1/network_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:yandex/cloud/serverless/functions/v1/network_service.proto\x12$yandex.cloud.serverless.functions.v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1dyandex/cloud/validation.proto\"\xb0\x02\n\x0bUsedNetwork\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12H\n\x06status\x18\x04 \x01(\x0e\x32\x38.yandex.cloud.serverless.functions.v1.UsedNetwork.Status\x12\x39\n\x15will_be_cleaned_up_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11\x63onnections_count\x18\x06 \x01(\x03\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08OBSOLETE\x10\x03\"1\n\x15GetUsedNetworkRequest\x12\x18\n\nnetwork_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8f\x01\n\x17ListUsedNetworksRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x12\n\x08\x63loud_id\x18\x03 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x04 \x01(\tH\x00\x42\r\n\x05scope\x12\x04\xc0\xc1\x31\x01\"x\n\x18ListUsedNetworksResponse\x12\x43\n\x08networks\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.serverless.functions.v1.UsedNetwork\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb3\x01\n\x1dListConnectedResourcesRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x14\n\nnetwork_id\x18\x03 \x01(\tH\x00\x12\x12\n\x08\x63loud_id\x18\x04 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x05 \x01(\tH\x00\x42\x15\n\rnetwork_scope\x12\x04\xc0\xc1\x31\x01\"\xe3\x02\n\x1eListConnectedResourcesResponse\x12i\n\tresources\x18\x01 \x03(\x0b\x32V.yandex.cloud.serverless.functions.v1.ListConnectedResourcesResponse.ConnectedResource\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x1a\xbc\x01\n\x11\x43onnectedResource\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x18\n\x10subresource_type\x18\x04 \x01(\t\x12\x16\n\x0esubresource_id\x18\x05 \x01(\t\x12\x19\n\x11resource_cloud_id\x18\x06 \x01(\t\x12\x1a\n\x12resource_folder_id\x18\x07 \x01(\t\"<\n TriggerUsedNetworkCleanupRequest\x12\x18\n\nnetwork_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"]\n!TriggerUsedNetworkCleanupResponse\x12\x38\n\x14network_cleanup_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp2\xe5\x04\n\x0eNetworkService\x12y\n\x07GetUsed\x12;.yandex.cloud.serverless.functions.v1.GetUsedNetworkRequest\x1a\x31.yandex.cloud.serverless.functions.v1.UsedNetwork\x12\x89\x01\n\x08ListUsed\x12=.yandex.cloud.serverless.functions.v1.ListUsedNetworksRequest\x1a>.yandex.cloud.serverless.functions.v1.ListUsedNetworksResponse\x12\xa3\x01\n\x16ListConnectedResources\x12\x43.yandex.cloud.serverless.functions.v1.ListConnectedResourcesRequest\x1a\x44.yandex.cloud.serverless.functions.v1.ListConnectedResourcesResponse\x12\xa5\x01\n\x12TriggerUsedCleanup\x12\x46.yandex.cloud.serverless.functions.v1.TriggerUsedNetworkCleanupRequest\x1aG.yandex.cloud.serverless.functions.v1.TriggerUsedNetworkCleanupResponseB~\n(yandex.cloud.api.serverless.functions.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/functions/v1;functionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.functions.v1.network_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n(yandex.cloud.api.serverless.functions.v1ZRgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/functions/v1;functions'
  _GETUSEDNETWORKREQUEST.fields_by_name['network_id']._options = None
  _GETUSEDNETWORKREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001'
  _LISTUSEDNETWORKSREQUEST.oneofs_by_name['scope']._options = None
  _LISTUSEDNETWORKSREQUEST.oneofs_by_name['scope']._serialized_options = b'\300\3011\001'
  _LISTUSEDNETWORKSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSEDNETWORKSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTUSEDNETWORKSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSEDNETWORKSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _LISTCONNECTEDRESOURCESREQUEST.oneofs_by_name['network_scope']._options = None
  _LISTCONNECTEDRESOURCESREQUEST.oneofs_by_name['network_scope']._serialized_options = b'\300\3011\001'
  _LISTCONNECTEDRESOURCESREQUEST.fields_by_name['page_size']._options = None
  _LISTCONNECTEDRESOURCESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\006<=1000'
  _LISTCONNECTEDRESOURCESREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTEDRESOURCESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _TRIGGERUSEDNETWORKCLEANUPREQUEST.fields_by_name['network_id']._options = None
  _TRIGGERUSEDNETWORKCLEANUPREQUEST.fields_by_name['network_id']._serialized_options = b'\350\3071\001'
  _globals['_USEDNETWORK']._serialized_start=165
  _globals['_USEDNETWORK']._serialized_end=469
  _globals['_USEDNETWORK_STATUS']._serialized_start=397
  _globals['_USEDNETWORK_STATUS']._serialized_end=469
  _globals['_GETUSEDNETWORKREQUEST']._serialized_start=471
  _globals['_GETUSEDNETWORKREQUEST']._serialized_end=520
  _globals['_LISTUSEDNETWORKSREQUEST']._serialized_start=523
  _globals['_LISTUSEDNETWORKSREQUEST']._serialized_end=666
  _globals['_LISTUSEDNETWORKSRESPONSE']._serialized_start=668
  _globals['_LISTUSEDNETWORKSRESPONSE']._serialized_end=788
  _globals['_LISTCONNECTEDRESOURCESREQUEST']._serialized_start=791
  _globals['_LISTCONNECTEDRESOURCESREQUEST']._serialized_end=970
  _globals['_LISTCONNECTEDRESOURCESRESPONSE']._serialized_start=973
  _globals['_LISTCONNECTEDRESOURCESRESPONSE']._serialized_end=1328
  _globals['_LISTCONNECTEDRESOURCESRESPONSE_CONNECTEDRESOURCE']._serialized_start=1140
  _globals['_LISTCONNECTEDRESOURCESRESPONSE_CONNECTEDRESOURCE']._serialized_end=1328
  _globals['_TRIGGERUSEDNETWORKCLEANUPREQUEST']._serialized_start=1330
  _globals['_TRIGGERUSEDNETWORKCLEANUPREQUEST']._serialized_end=1390
  _globals['_TRIGGERUSEDNETWORKCLEANUPRESPONSE']._serialized_start=1392
  _globals['_TRIGGERUSEDNETWORKCLEANUPRESPONSE']._serialized_end=1485
  _globals['_NETWORKSERVICE']._serialized_start=1488
  _globals['_NETWORKSERVICE']._serialized_end=2101
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datasphere/v2/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'yandex/cloud/datasphere/v2/secret.proto\x12\x1ayandex.cloud.datasphere.v2\x1a\x1fgoogle/protobuf/timestamp.proto\"\xbd\x02\n\x06Secret\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12>\n\x06labels\x18\x06 \x03(\x0b\x32..yandex.cloud.datasphere.v2.Secret.LabelsEntry\x12\x15\n\rcreated_by_id\x18\x07 \x01(\t\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0b\"V\n\x0f\x44\x65\x63ryptedSecret\x12\x32\n\x06secret\x18\x01 \x01(\x0b\x32\".yandex.cloud.datasphere.v2.Secret\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\tBk\n\x1eyandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphereb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datasphere.v2.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036yandex.cloud.api.datasphere.v2ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/datasphere/v2;datasphere'
  _SECRET_LABELSENTRY._options = None
  _SECRET_LABELSENTRY._serialized_options = b'8\001'
  _globals['_SECRET']._serialized_start=105
  _globals['_SECRET']._serialized_end=422
  _globals['_SECRET_LABELSENTRY']._serialized_start=365
  _globals['_SECRET_LABELSENTRY']._serialized_end=410
  _globals['_DECRYPTEDSECRET']._serialized_start=424
  _globals['_DECRYPTEDSECRET']._serialized_end=510
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/config_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4yandex/cloud/loadtesting/api/v1/config_service.proto\x12\x1fyandex.cloud.loadtesting.api.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/operation/operation.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\"W\n\x13\x43reateConfigRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x15\n\x0byaml_string\x18\x02 \x01(\tH\x00\x42\x08\n\x06\x63onfig\")\n\x14\x43reateConfigMetadata\x12\x11\n\tconfig_id\x18\x01 \x01(\t2\xc4\x01\n\rConfigService\x12\xb2\x01\n\x06\x43reate\x12\x34.yandex.cloud.loadtesting.api.v1.CreateConfigRequest\x1a!.yandex.cloud.operation.Operation\"O\xb2\xd2*%\n\x14\x43reateConfigMetadata\x12\rconfig.Config\x82\xd3\xe4\x93\x02 \"\x1b/loadtesting/api/v1/configs:\x01*Bv\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtestingb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.config_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n#yandex.cloud.api.loadtesting.api.v1ZOgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1;loadtesting'
  _CREATECONFIGREQUEST.fields_by_name['folder_id']._options = None
  _CREATECONFIGREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CONFIGSERVICE.methods_by_name['Create']._options = None
  _CONFIGSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*%\n\024CreateConfigMetadata\022\rconfig.Config\202\323\344\223\002 \"\033/loadtesting/api/v1/configs:\001*'
  _globals['_CREATECONFIGREQUEST']._serialized_start=224
  _globals['_CREATECONFIGREQUEST']._serialized_end=311
  _globals['_CREATECONFIGMETADATA']._serialized_start=313
  _globals['_CREATECONFIGMETADATA']._serialized_end=354
  _globals['_CONFIGSERVICE']._serialized_start=357
  _globals['_CONFIGSERVICE']._serialized_end=553
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/triggers/v1/trigger.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1yandex/cloud/serverless/triggers/v1/trigger.proto\x12#yandex.cloud.serverless.triggers.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\x93(\n\x07Trigger\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x04name\x18\x04 \x01(\tB\x08\x8a\xc8\x31\x04\x33-63\x12\x1e\n\x0b\x64\x65scription\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05\x30-256\x12H\n\x06labels\x18\x06 \x03(\x0b\x32\x38.yandex.cloud.serverless.triggers.v1.Trigger.LabelsEntry\x12\x45\n\x04rule\x18\x08 \x01(\x0b\x32\x31.yandex.cloud.serverless.triggers.v1.Trigger.RuleB\x04\xe8\xc7\x31\x01\x12\x43\n\x06status\x18\t \x01(\x0e\x32\x33.yandex.cloud.serverless.triggers.v1.Trigger.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xf6\x06\n\x04Rule\x12\x43\n\x05timer\x18\x02 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.Trigger.TimerH\x00\x12R\n\rmessage_queue\x18\x03 \x01(\x0b\x32\x39.yandex.cloud.serverless.triggers.v1.Trigger.MessageQueueH\x00\x12N\n\x0biot_message\x18\x04 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.Trigger.IoTMessageH\x00\x12[\n\x12iot_broker_message\x18\x0e \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.Trigger.IoTBrokerMessageH\x00\x12T\n\x0eobject_storage\x18\x05 \x01(\x0b\x32:.yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorageH\x00\x12\\\n\x12\x63ontainer_registry\x18\x06 \x01(\x0b\x32>.yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistryH\x00\x12L\n\ncloud_logs\x18\t \x01(\x0b\x32\x36.yandex.cloud.serverless.triggers.v1.Trigger.CloudLogsH\x00\x12G\n\x07logging\x18\n \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.Trigger.LoggingH\x00\x12L\n\x0e\x62illing_budget\x18\x0b \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BillingBudgetH\x00\x12\x46\n\x0b\x64\x61ta_stream\x18\x0c \x01(\x0b\x32/.yandex.cloud.serverless.triggers.v1.DataStreamH\x00\x12\x39\n\x04mail\x18\r \x01(\x0b\x32).yandex.cloud.serverless.triggers.v1.MailH\x00\x42\x0c\n\x04rule\x12\x04\xc0\xc1\x31\x01\x1a\xfa\x02\n\x05Timer\x12&\n\x0f\x63ron_expression\x18\x01 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\x1b\n\x07payload\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=4096\x12R\n\x0finvoke_function\x18\x65 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.InvokeFunctionOnceH\x00\x12\x62\n\x1ainvoke_function_with_retry\x18g \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12\x64\n\x1binvoke_container_with_retry\x18h \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\x9e\x03\n\x0cMessageQueue\x12\x16\n\x08queue_id\x18\x0b \x01(\tB\x04\xe8\xc7\x31\x01\x12(\n\x12service_account_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12P\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettingsB\x04\xe8\xc7\x31\x01\x12@\n\x12visibility_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05<=12h\x12R\n\x0finvoke_function\x18\x65 \x01(\x0b\x32\x37.yandex.cloud.serverless.triggers.v1.InvokeFunctionOnceH\x00\x12T\n\x10invoke_container\x18\x66 \x01(\x0b\x32\x38.yandex.cloud.serverless.triggers.v1.InvokeContainerOnceH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xde\x02\n\nIoTMessage\x12\x19\n\x0bregistry_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x11\n\tdevice_id\x18\x02 \x01(\t\x12\x12\n\nmqtt_topic\x18\x03 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xcf\x02\n\x10IoTBrokerMessage\x12\x17\n\tbroker_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x12\n\nmqtt_topic\x18\x02 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xb3\x03\n\rObjectStorage\x12_\n\nevent_type\x18\x03 \x03(\x0e\x32\x43.yandex.cloud.serverless.triggers.v1.Trigger.ObjectStorageEventTypeB\x06\x82\xc8\x31\x02>0\x12\x11\n\tbucket_id\x18\x04 \x01(\t\x12\x0e\n\x06prefix\x18\x06 \x01(\t\x12\x0e\n\x06suffix\x18\x07 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xbe\x03\n\x11\x43ontainerRegistry\x12\x63\n\nevent_type\x18\x03 \x03(\x0e\x32G.yandex.cloud.serverless.triggers.v1.Trigger.ContainerRegistryEventTypeB\x06\x82\xc8\x31\x02>0\x12\x13\n\x0bregistry_id\x18\x04 \x01(\t\x12\x12\n\nimage_name\x18\x05 \x01(\t\x12\x0b\n\x03tag\x18\x06 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x07 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xc0\x02\n\tCloudLogs\x12\x14\n\x0clog_group_id\x18\x01 \x03(\t\x12Y\n\x0e\x62\x61tch_settings\x18\x02 \x01(\x0b\x32;.yandex.cloud.serverless.triggers.v1.CloudLogsBatchSettingsB\x04\xe8\xc7\x31\x01\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x66 \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\x1a\xcc\x04\n\x07Logging\x12\x1e\n\x0clog_group_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12@\n\rresource_type\x18\x03 \x03(\tB)\xf2\xc7\x31\x1c[a-zA-Z][-a-zA-Z0-9_.]{1,62}\x82\xc8\x31\x05<=100\x12>\n\x0bresource_id\x18\x04 \x03(\tB)\xf2\xc7\x31\x1c[a-zA-Z][-a-zA-Z0-9_.]{1,62}\x82\xc8\x31\x05<=100\x12?\n\x0bstream_name\x18\x07 \x03(\tB*\xf2\xc7\x31\x1d|[a-z][-a-z0-9]{1,61}[a-z0-9]\x82\xc8\x31\x05<=100\x12\x41\n\x06levels\x18\x05 \x03(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\x08\x82\xc8\x31\x04<=10\x12W\n\x0e\x62\x61tch_settings\x18\x06 \x01(\x0b\x32\x39.yandex.cloud.serverless.triggers.v1.LoggingBatchSettingsB\x04\xe8\xc7\x31\x01\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"\xca\x01\n\x16ObjectStorageEventType\x12)\n%OBJECT_STORAGE_EVENT_TYPE_UNSPECIFIED\x10\x00\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_CREATE_OBJECT\x10\x01\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_UPDATE_OBJECT\x10\x02\x12+\n\'OBJECT_STORAGE_EVENT_TYPE_DELETE_OBJECT\x10\x03\"\x93\x02\n\x1a\x43ontainerRegistryEventType\x12-\n)CONTAINER_REGISTRY_EVENT_TYPE_UNSPECIFIED\x10\x00\x12.\n*CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE\x10\x01\x12.\n*CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE\x10\x02\x12\x32\n.CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE_TAG\x10\x03\x12\x32\n.CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE_TAG\x10\x04\"8\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\n\n\x06PAUSED\x10\x02\"i\n\x12InvokeFunctionOnce\x12!\n\x0b\x66unction_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x0c\x66unction_tag\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x03 \x01(\t\"\x8b\x02\n\x17InvokeFunctionWithRetry\x12!\n\x0b\x66unction_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x14\n\x0c\x66unction_tag\x18\x02 \x01(\t\x12\x1a\n\x12service_account_id\x18\x03 \x01(\t\x12J\n\x0eretry_settings\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.RetrySettings\x12O\n\x11\x64\x65\x61\x64_letter_queue\x18\x05 \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.PutQueueMessage\"c\n\x13InvokeContainerOnce\x12\"\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\"\x85\x02\n\x18InvokeContainerWithRetry\x12\"\n\x0c\x63ontainer_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12J\n\x0eretry_settings\x18\x05 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.RetrySettings\x12O\n\x11\x64\x65\x61\x64_letter_queue\x18\x06 \x01(\x0b\x32\x34.yandex.cloud.serverless.triggers.v1.PutQueueMessage\"M\n\x0fPutQueueMessage\x12\x10\n\x08queue_id\x18\x0b \x01(\t\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"X\n\rBatchSettings\x12\x16\n\x04size\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-10\x12/\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x04\xe8\xc7\x31\x01\"g\n\x16\x43loudLogsBatchSettings\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x30-100\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"e\n\x14LoggingBatchSettings\x12\x17\n\x04size\x18\x01 \x01(\x03\x42\t\xfa\xc7\x31\x05\x31-100\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"m\n\rRetrySettings\x12\x1f\n\x0eretry_attempts\x18\x01 \x01(\x03\x42\x07\xfa\xc7\x31\x03\x31-5\x12;\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\xe8\xc7\x31\x01\xfa\xc7\x31\x06\x31\x30s-1m\"\x9a\x02\n\rBillingBudget\x12(\n\x12\x62illing_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\tbudget_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"j\n\x17\x44\x61taStreamBatchSettings\x12\x19\n\x04size\x18\x01 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31-65536\x12\x34\n\x06\x63utoff\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\xfa\xc7\x31\x05\x31s-1m\"\xf6\x02\n\nDataStream\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0e\n\x06stream\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12T\n\x0e\x62\x61tch_settings\x18\x05 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.DataStreamBatchSettings\x12W\n\x0finvoke_function\x18\r \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18\x0f \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01\"v\n\x1bObjectStorageBucketSettings\x12-\n\tbucket_id\x18\x01 \x01(\tB\x1a\xf2\xc7\x31\x0e[-.0-9a-zA-Z]*\x8a\xc8\x31\x04\x33-63\x12(\n\x12service_account_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x83\x03\n\x04Mail\x12\r\n\x05\x65mail\x18\x02 \x01(\t\x12J\n\x0e\x62\x61tch_settings\x18\x03 \x01(\x0b\x32\x32.yandex.cloud.serverless.triggers.v1.BatchSettings\x12\\\n\x12\x61ttachments_bucket\x18\x04 \x01(\x0b\x32@.yandex.cloud.serverless.triggers.v1.ObjectStorageBucketSettings\x12W\n\x0finvoke_function\x18\x65 \x01(\x0b\x32<.yandex.cloud.serverless.triggers.v1.InvokeFunctionWithRetryH\x00\x12Y\n\x10invoke_container\x18g \x01(\x0b\x32=.yandex.cloud.serverless.triggers.v1.InvokeContainerWithRetryH\x00\x42\x0e\n\x06\x61\x63tion\x12\x04\xc0\xc1\x31\x01*\xe2\x01\n\x0bTriggerType\x12\x1c\n\x18TRIGGER_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05TIMER\x10\x02\x12\x11\n\rMESSAGE_QUEUE\x10\x03\x12\x0f\n\x0bIOT_MESSAGE\x10\x04\x12\x16\n\x12IOT_BROKER_MESSAGE\x10\x0c\x12\x12\n\x0eOBJECT_STORAGE\x10\x05\x12\x16\n\x12\x43ONTAINER_REGISTRY\x10\x06\x12\x0e\n\nCLOUD_LOGS\x10\x07\x12\x0b\n\x07LOGGING\x10\x08\x12\x12\n\x0e\x42ILLING_BUDGET\x10\t\x12\x07\n\x03YDS\x10\n\x12\x08\n\x04MAIL\x10\x0b\x42{\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggersb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.triggers.v1.trigger_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.serverless.triggers.v1ZPgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/triggers/v1;triggers'
  _TRIGGER_LABELSENTRY._options = None
  _TRIGGER_LABELSENTRY._serialized_options = b'8\001'
  _TRIGGER_RULE.oneofs_by_name['rule']._options = None
  _TRIGGER_RULE.oneofs_by_name['rule']._serialized_options = b'\300\3011\001'
  _TRIGGER_TIMER.oneofs_by_name['action']._options = None
  _TRIGGER_TIMER.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _TRIGGER_TIMER.fields_by_name['cron_expression']._options = None
  _TRIGGER_TIMER.fields_by_name['cron_expression']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _TRIGGER_TIMER.fields_by_name['payload']._options = None
  _TRIGGER_TIMER.fields_by_name['payload']._serialized_options = b'\212\3101\006<=4096'
  _TRIGGER_MESSAGEQUEUE.oneofs_by_name['action']._options = None
  _TRIGGER_MESSAGEQUEUE.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _TRIGGER_MESSAGEQUEUE.fields_by_name['queue_id']._options = None
  _TRIGGER_MESSAGEQUEUE.fields_by_name['queue_id']._serialized_options = b'\350\3071\001'
  _TRIGGER_MESSAGEQUEUE.fields_by_name['service_account_id']._options = None
  _TRIGGER_MESSAGEQUEUE.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _TRIGGER_MESSAGEQUEUE.fields_by_name['batch_settings']._options = None
  _TRIGGER_MESSAGEQUEUE.fields_by_name['batch_settings']._serialized_options = b'\350\3071\001'
  _TRIGGER_MESSAGEQUEUE.fields_by_name['visibility_timeout']._options = None
  _TRIGGER_MESSAGEQUEUE.fields_by_name['visibility_timeout']._serialized_options = b'\372\3071\005<=12h'
  _TRIGGER_IOTMESSAGE.oneofs_by_name['action']._options = None
  _TRIGGER_IOTMESSAGE.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _TRIGGER_IOTMESSAGE.fields_by_name['registry_id']._options = None
  _TRIGGER_IOTMESSAGE.fields_by_name['registry_id']._serialized_options = b'\350\3071\001'
  _TRIGGER_IOTBROKERMESSAGE.oneofs_by_name['action']._options = None
  _TRIGGER_IOTBROKERMESSAGE.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _TRIGGER_IOTBROKERMESSAGE.fields_by_name['broker_id']._options = None
  _TRIGGER_IOTBROKERMESSAGE.fields_by_name['broker_id']._serialized_options = b'\350\3071\001'
  _TRIGGER_OBJECTSTORAGE.oneofs_by_name['action']._options = None
  _TRIGGER_OBJECTSTORAGE.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _TRIGGER_OBJECTSTORAGE.fields_by_name['event_type']._options = None
  _TRIGGER_OBJECTSTORAGE.fields_by_name['event_type']._serialized_options = b'\202\3101\002>0'
  _TRIGGER_CONTAINERREGISTRY.oneofs_by_name['action']._options = None
  _TRIGGER_CONTAINERREGISTRY.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _TRIGGER_CONTAINERREGISTRY.fields_by_name['event_type']._options = None
  _TRIGGER_CONTAINERREGISTRY.fields_by_name['event_type']._serialized_options = b'\202\3101\002>0'
  _TRIGGER_CLOUDLOGS.oneofs_by_name['action']._options = None
  _TRIGGER_CLOUDLOGS.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _TRIGGER_CLOUDLOGS.fields_by_name['batch_settings']._options = None
  _TRIGGER_CLOUDLOGS.fields_by_name['batch_settings']._serialized_options = b'\350\3071\001'
  _TRIGGER_LOGGING.oneofs_by_name['action']._options = None
  _TRIGGER_LOGGING.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _TRIGGER_LOGGING.fields_by_name['log_group_id']._options = None
  _TRIGGER_LOGGING.fields_by_name['log_group_id']._serialized_options = b'\212\3101\004<=50'
  _TRIGGER_LOGGING.fields_by_name['resource_type']._options = None
  _TRIGGER_LOGGING.fields_by_name['resource_type']._serialized_options = b'\362\3071\034[a-zA-Z][-a-zA-Z0-9_.]{1,62}\202\3101\005<=100'
  _TRIGGER_LOGGING.fields_by_name['resource_id']._options = None
  _TRIGGER_LOGGING.fields_by_name['resource_id']._serialized_options = b'\362\3071\034[a-zA-Z][-a-zA-Z0-9_.]{1,62}\202\3101\005<=100'
  _TRIGGER_LOGGING.fields_by_name['stream_name']._options = None
  _TRIGGER_LOGGING.fields_by_name['stream_name']._serialized_options = b'\362\3071\035|[a-z][-a-z0-9]{1,61}[a-z0-9]\202\3101\005<=100'
  _TRIGGER_LOGGING.fields_by_name['levels']._options = None
  _TRIGGER_LOGGING.fields_by_name['levels']._serialized_options = b'\202\3101\004<=10'
  _TRIGGER_LOGGING.fields_by_name['batch_settings']._options = None
  _TRIGGER_LOGGING.fields_by_name['batch_settings']._serialized_options = b'\350\3071\001'
  _TRIGGER.fields_by_name['folder_id']._options = None
  _TRIGGER.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _TRIGGER.fields_by_name['name']._options = None
  _TRIGGER.fields_by_name['name']._serialized_options = b'\212\3101\0043-63'
  _TRIGGER.fields_by_name['description']._options = None
  _TRIGGER.fields_by_name['description']._serialized_options = b'\212\3101\0050-256'
  _TRIGGER.fields_by_name['rule']._options = None
  _TRIGGER.fields_by_name['rule']._serialized_options = b'\350\3071\001'
  _INVOKEFUNCTIONONCE.fields_by_name['function_id']._options = None
  _INVOKEFUNCTIONONCE.fields_by_name['function_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _INVOKEFUNCTIONWITHRETRY.fields_by_name['function_id']._options = None
  _INVOKEFUNCTIONWITHRETRY.fields_by_name['function_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _INVOKECONTAINERONCE.fields_by_name['container_id']._options = None
  _INVOKECONTAINERONCE.fields_by_name['container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _INVOKECONTAINERWITHRETRY.fields_by_name['container_id']._options = None
  _INVOKECONTAINERWITHRETRY.fields_by_name['container_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _PUTQUEUEMESSAGE.fields_by_name['service_account_id']._options = None
  _PUTQUEUEMESSAGE.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BATCHSETTINGS.fields_by_name['size']._options = None
  _BATCHSETTINGS.fields_by_name['size']._serialized_options = b'\372\3071\0040-10'
  _BATCHSETTINGS.fields_by_name['cutoff']._options = None
  _BATCHSETTINGS.fields_by_name['cutoff']._serialized_options = b'\350\3071\001'
  _CLOUDLOGSBATCHSETTINGS.fields_by_name['size']._options = None
  _CLOUDLOGSBATCHSETTINGS.fields_by_name['size']._serialized_options = b'\372\3071\0050-100'
  _CLOUDLOGSBATCHSETTINGS.fields_by_name['cutoff']._options = None
  _CLOUDLOGSBATCHSETTINGS.fields_by_name['cutoff']._serialized_options = b'\372\3071\0051s-1m'
  _LOGGINGBATCHSETTINGS.fields_by_name['size']._options = None
  _LOGGINGBATCHSETTINGS.fields_by_name['size']._serialized_options = b'\372\3071\0051-100'
  _LOGGINGBATCHSETTINGS.fields_by_name['cutoff']._options = None
  _LOGGINGBATCHSETTINGS.fields_by_name['cutoff']._serialized_options = b'\372\3071\0051s-1m'
  _RETRYSETTINGS.fields_by_name['retry_attempts']._options = None
  _RETRYSETTINGS.fields_by_name['retry_attempts']._serialized_options = b'\372\3071\0031-5'
  _RETRYSETTINGS.fields_by_name['interval']._options = None
  _RETRYSETTINGS.fields_by_name['interval']._serialized_options = b'\350\3071\001\372\3071\00610s-1m'
  _BILLINGBUDGET.oneofs_by_name['action']._options = None
  _BILLINGBUDGET.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _BILLINGBUDGET.fields_by_name['billing_account_id']._options = None
  _BILLINGBUDGET.fields_by_name['billing_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _BILLINGBUDGET.fields_by_name['budget_id']._options = None
  _BILLINGBUDGET.fields_by_name['budget_id']._serialized_options = b'\212\3101\004<=50'
  _DATASTREAMBATCHSETTINGS.fields_by_name['size']._options = None
  _DATASTREAMBATCHSETTINGS.fields_by_name['size']._serialized_options = b'\372\3071\0071-65536'
  _DATASTREAMBATCHSETTINGS.fields_by_name['cutoff']._options = None
  _DATASTREAMBATCHSETTINGS.fields_by_name['cutoff']._serialized_options = b'\372\3071\0051s-1m'
  _DATASTREAM.oneofs_by_name['action']._options = None
  _DATASTREAM.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _OBJECTSTORAGEBUCKETSETTINGS.fields_by_name['bucket_id']._options = None
  _OBJECTSTORAGEBUCKETSETTINGS.fields_by_name['bucket_id']._serialized_options = b'\362\3071\016[-.0-9a-zA-Z]*\212\3101\0043-63'
  _OBJECTSTORAGEBUCKETSETTINGS.fields_by_name['service_account_id']._options = None
  _OBJECTSTORAGEBUCKETSETTINGS.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MAIL.oneofs_by_name['action']._options = None
  _MAIL.oneofs_by_name['action']._serialized_options = b'\300\3011\001'
  _globals['_TRIGGERTYPE']._serialized_start=7880
  _globals['_TRIGGERTYPE']._serialized_end=8106
  _globals['_TRIGGER']._serialized_start=228
  _globals['_TRIGGER']._serialized_end=5367
  _globals['_TRIGGER_LABELSENTRY']._serialized_start=602
  _globals['_TRIGGER_LABELSENTRY']._serialized_end=647
  _globals['_TRIGGER_RULE']._serialized_start=650
  _globals['_TRIGGER_RULE']._serialized_end=1536
  _globals['_TRIGGER_TIMER']._serialized_start=1539
  _globals['_TRIGGER_TIMER']._serialized_end=1917
  _globals['_TRIGGER_MESSAGEQUEUE']._serialized_start=1920
  _globals['_TRIGGER_MESSAGEQUEUE']._serialized_end=2334
  _globals['_TRIGGER_IOTMESSAGE']._serialized_start=2337
  _globals['_TRIGGER_IOTMESSAGE']._serialized_end=2687
  _globals['_TRIGGER_IOTBROKERMESSAGE']._serialized_start=2690
  _globals['_TRIGGER_IOTBROKERMESSAGE']._serialized_end=3025
  _globals['_TRIGGER_OBJECTSTORAGE']._serialized_start=3028
  _globals['_TRIGGER_OBJECTSTORAGE']._serialized_end=3463
  _globals['_TRIGGER_CONTAINERREGISTRY']._serialized_start=3466
  _globals['_TRIGGER_CONTAINERREGISTRY']._serialized_end=3912
  _globals['_TRIGGER_CLOUDLOGS']._serialized_start=3915
  _globals['_TRIGGER_CLOUDLOGS']._serialized_end=4235
  _globals['_TRIGGER_LOGGING']._serialized_start=4238
  _globals['_TRIGGER_LOGGING']._serialized_end=4826
  _globals['_TRIGGER_OBJECTSTORAGEEVENTTYPE']._serialized_start=4829
  _globals['_TRIGGER_OBJECTSTORAGEEVENTTYPE']._serialized_end=5031
  _globals['_TRIGGER_CONTAINERREGISTRYEVENTTYPE']._serialized_start=5034
  _globals['_TRIGGER_CONTAINERREGISTRYEVENTTYPE']._serialized_end=5309
  _globals['_TRIGGER_STATUS']._serialized_start=5311
  _globals['_TRIGGER_STATUS']._serialized_end=5367
  _globals['_INVOKEFUNCTIONONCE']._serialized_start=5369
  _globals['_INVOKEFUNCTIONONCE']._serialized_end=5474
  _globals['_INVOKEFUNCTIONWITHRETRY']._serialized_start=5477
  _globals['_INVOKEFUNCTIONWITHRETRY']._serialized_end=5744
  _globals['_INVOKECONTAINERONCE']._serialized_start=5746
  _globals['_INVOKECONTAINERONCE']._serialized_end=5845
  _globals['_INVOKECONTAINERWITHRETRY']._serialized_start=5848
  _globals['_INVOKECONTAINERWITHRETRY']._serialized_end=6109
  _globals['_PUTQUEUEMESSAGE']._serialized_start=6111
  _globals['_PUTQUEUEMESSAGE']._serialized_end=6188
  _globals['_BATCHSETTINGS']._serialized_start=6190
  _globals['_BATCHSETTINGS']._serialized_end=6278
  _globals['_CLOUDLOGSBATCHSETTINGS']._serialized_start=6280
  _globals['_CLOUDLOGSBATCHSETTINGS']._serialized_end=6383
  _globals['_LOGGINGBATCHSETTINGS']._serialized_start=6385
  _globals['_LOGGINGBATCHSETTINGS']._serialized_end=6486
  _globals['_RETRYSETTINGS']._serialized_start=6488
  _globals['_RETRYSETTINGS']._serialized_end=6597
  _globals['_BILLINGBUDGET']._serialized_start=6600
  _globals['_BILLINGBUDGET']._serialized_end=6882
  _globals['_DATASTREAMBATCHSETTINGS']._serialized_start=6884
  _globals['_DATASTREAMBATCHSETTINGS']._serialized_end=6990
  _globals['_DATASTREAM']._serialized_start=6993
  _globals['_DATASTREAM']._serialized_end=7367
  _globals['_OBJECTSTORAGEBUCKETSETTINGS']._serialized_start=7369
  _globals['_OBJECTSTORAGEBUCKETSETTINGS']._serialized_end=7487
  _globals['_MAIL']._serialized_start=7490
  _globals['_MAIL']._serialized_end=7877
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/backup/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/backup/v1/resource.proto\x12\x16yandex.cloud.backup.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\x88\x04\n\x08Resource\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12.\n\ncreated_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06online\x18\x04 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x05 \x01(\x08\x12\x37\n\x06status\x18\x06 \x01(\x0e\x32\'.yandex.cloud.backup.v1.Resource.Status\x12\x16\n\x0estatus_details\x18\x07 \x01(\t\x12\x17\n\x0fstatus_progress\x18\x08 \x01(\x03\x12\x34\n\x10last_backup_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10next_backup_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0bresource_id\x18\x0b \x01(\t\x12\x11\n\tis_active\x18\x0c \x01(\x08\"`\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x08\n\x04IDLE\x10\x01\x12\r\n\tBACKUPING\x10\x02\x12\x0e\n\nRECOVERING\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x12\t\n\x05OTHER\x10\x05\"*\n\x08Progress\x12\x0f\n\x07\x63urrent\x18\x01 \x01(\x03\x12\r\n\x05total\x18\x02 \x01(\x03\"\xe1\x04\n\x04Task\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x13\n\x0b\x63\x61ncellable\x18\x02 \x01(\x08\x12\x11\n\tpolicy_id\x18\x03 \x01(\t\x12/\n\x04type\x18\x04 \x01(\x0e\x32!.yandex.cloud.backup.v1.Task.Type\x12\x32\n\x08progress\x18\x05 \x01(\x0b\x32 .yandex.cloud.backup.v1.Progress\x12\x33\n\x06status\x18\x06 \x01(\x0e\x32#.yandex.cloud.backup.v1.Task.Status\x12/\n\x0b\x65nqueued_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63ompleted_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13\x63ompute_instance_id\x18\x0b \x01(\t\"E\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\n\n\x06\x42\x41\x43KUP\x10\x01\x12\r\n\tRETENTION\x10\x02\x12\x0c\n\x08RECOVERY\x10\x03\"d\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x45NQUEUED\x10\x01\x12\x0c\n\x08\x41SSIGNED\x10\x02\x12\x0b\n\x07STARTED\x10\x03\x12\n\n\x06PAUSED\x10\x04\x12\r\n\tCOMPLETED\x10\x05\x42_\n\x1ayandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.backup.v1.resource_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backup'
  _globals['_RESOURCE']._serialized_start=99
  _globals['_RESOURCE']._serialized_end=619
  _globals['_RESOURCE_STATUS']._serialized_start=523
  _globals['_RESOURCE_STATUS']._serialized_end=619
  _globals['_PROGRESS']._serialized_start=621
  _globals['_PROGRESS']._serialized_end=663
  _globals['_TASK']._serialized_start=666
  _globals['_TASK']._serialized_end=1275
  _globals['_TASK_TYPE']._serialized_start=1104
  _globals['_TASK_TYPE']._serialized_end=1173
  _globals['_TASK_STATUS']._serialized_start=1175
  _globals['_TASK_STATUS']._serialized_end=1275
# @@protoc_insertion_point(module_scope)
